package com.lzmispt.data.resource.service.lzdpdevelop.impl;

package .tmp;

import com.alibaba.fastjson.JSON;
import com.alibaba.nacos.client.naming.utils.CollectionUtils;
import com.lzmispt.core.entity.coreconst.CoreConst;
import com.lzmispt.core.entity.dto.authorize.GetDataAuthorizeInfoDTO;
import com.lzmispt.core.entity.dto.querymodel.QueryModelDTO;
import com.lzmispt.core.entity.dto.querymodel.SortModelDTO;
import com.lzmispt.core.entity.vo.authorize.DataAuthorizeItemFunInfoVO;
import com.lzmispt.core.entity.vo.authorize.GetDataAuthorizeInfoVO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.DataDesensitizeDTO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.GetDataDTO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.GetLZDPDataDTO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.GetTableDTO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.GetTableTreeDTO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.OperateLogDTO;
import com.lzmispt.data.center.entity.dto.resource.metadata.EntityItemInfoSearchDTO;
import com.lzmispt.data.center.entity.dto.resource.metadata.GetDirectoryTreeDataDTO;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.desensitse.DesensitseRule;
import com.lzmispt.data.center.entity.vo.resource.lzdpdevelop.FieldVO;
import com.lzmispt.data.center.entity.vo.resource.lzdpdevelop.TableTreeVO;
import com.lzmispt.data.center.entity.vo.resource.lzdpdevelop.TableVO;
import com.lzmispt.data.center.entity.vo.resource.metadata.DirectoryTreeVO;
import com.lzmispt.data.center.entity.vo.resource.metadata.MetadataDirectoryVO;
import com.lzmispt.data.center.entity.vo.resource.metadata.MetadataFieldVO;
import com.lzmispt.data.resource.client.CoreClient;
import com.lzmispt.data.resource.client.DataApplyClient;
import com.lzmispt.data.resource.client.IndicatorClient;
import com.lzmispt.data.resource.dao.desensitize.IDataDesensitizeDao;
import com.lzmispt.data.resource.entity.dto.resanddata.ResAndDataDirectoryDTO;
import com.lzmispt.data.resource.entity.po.desensitize.DataDesensitizePO;
import com.lzmispt.data.resource.entity.po.metadata.MetadataEntityInfoItemPO;
import com.lzmispt.data.resource.entity.vo.metadata.SelectMetadataEntityVO;
import com.lzmispt.data.resource.manager.metadata.MetadataManager;
import com.lzmispt.data.resource.service.desensitize.IDataDesensitizeService;
import com.lzmispt.data.resource.service.lzdpdevelop.ILZDPApi;
import com.lzmispt.data.resource.service.lzdpdevelop.impl.LzdpConfig;
import com.lzmispt.data.resource.service.lzdpdevelop.impl.LzdpConfigResult;
import com.lzmispt.data.resource.service.metadata.IDataResource;
import com.lzmispt.data.resource.service.metadata.IInfoItem;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.historytable.HistoryTableConfig;
import com.lzmispt.dcbase.log.CommonLogHelper;
import com.lzmispt.dcbase.util.DesensitizeUtil;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.exception.ExceptionUtil;
import com.lzmispt.framework.log.LogHelper;
import com.lzmispt.framework.utils.HttpClientUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.function.Supplier;
import java.util.stream.Collectors;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

@Service
public class LZDPApiImpl implements ILZDPApi {
  @Autowired
  private DataApplyClient dataApplyClient;
  
  @Autowired
  private CoreClient coreClient;
  
  @Autowired
  IDataDesensitizeDao iDataDesensitizeDao;
  
  @Autowired
  private HistoryTableConfig historyTableConfig;
  
  @Autowired
  private LzdpConfig lzdpConfig;
  
  @Autowired
  private IndicatorClient indicatorClient;
  
  @Value("${data-center.site-request-url.lzdp-api:null}")
  private String lzdpApi;
  
  public static final String SEPARATOR = "_";
  
  public static final String PLAT_HISTORY_MARK = "-History";
  
  public static final String DATABASE_ID = "100000000000000000";
  
  public static final String MANAGE_ROOT_TABLE_ID = "210000000000000000";
  
  public static final String COLLECTION_DATABASE_ID = "Collection_100000000000000000";
  
  public static final String COLLECTION_DATABASE_HISTORY_ID = "Collection-History_100000000000000000";
  
  public static final String INDICATOR_DATABASE_ID = "Indicator_100000000000000000";
  
  public static final String MANAGE_DATABASE_ID = "Manage_100000000000000000";
  
  public static final String MANAGE_DATABASE_HISTORY_ID = "Manage-History_100000000000000000";
  
  public static final String MANAGE_TABLE_ID = "Manage_210000000000000000";
  
  public static final String MANAGE_TABLE_HISTORY_ID = "Manage-History_210000000000000000";
  
  public static final String MANAGE_VIEW_ID = "Manage_220000000000000000";
  
  private final Map<String, Supplier<List<TableTreeVO>>> fixedLazyLoadTreeSupplier = initFixedChildrenLazyLoadTreeSupplier();
  
  private static final String INDEX_ANALYSIS = "index_analysis";
  
  private static final String SPECIAL_DATABASE = "special_database";
  
  private static final String INDICATOR = "Indicator";
  
  private static final String INDICATOR_CODE = "indicator";
  
  public List<TableTreeVO> getTableTree(GetTableTreeDTO getTableTreeDTO) {
    return getTableTree(getTableTreeDTO, this.lzdpConfig);
  }
  
  public List<TableTreeVO> getMonitorDataTableTree(GetTableTreeDTO getTableTreeDTO) {
    return getTableTree(getTableTreeDTO, this.lzdpConfig);
  }
  
  public List<TableTreeVO> getTableTree(GetTableTreeDTO getTableTreeDTO, LzdpConfig lzdpConfig) {
    CommonLogHelper.consoleInfo("文本过滤组件中按数据表选择没有显示相应的数据表和字段:" + JSON.toJSONString(getTableTreeDTO), DCConst.ServerClientType.RESOURCE);
    if (getTableTreeDTO.getInclude_field_info() == null)
      getTableTreeDTO.setInclude_field_info(Boolean.valueOf(false)); 
    if (getTableTreeDTO.getQuery() != null && !StringUtils.isEmpty(getTableTreeDTO.getQuery().getQuery_value()))
      getTableTreeDTO.setLazy_load(Boolean.valueOf(false)); 
    LzdpConfigResult lzdpTableSelectConfig = getLzdpTableSelectConfig();
    if (lzdpTableSelectConfig != null) {
      CommonLogHelper.consoleInfo("lzdp数据库配置信息:" + JSON.toJSONString(lzdpTableSelectConfig), DCConst.ServerClientType.RESOURCE);
    } else {
      CommonLogHelper.consoleError(null, "没有读取到lzdp数据库配置信息", DCConst.ServerClientType.RESOURCE);
      return new ArrayList<>();
    } 
    if (getTableTreeDTO.getParent_id() == null && getTableTreeDTO.getQuery() == null)
      return getPlatTree(getTableTreeDTO, lzdpTableSelectConfig); 
    if (getTableTreeDTO.getQuery() == null) {
      Supplier<List<TableTreeVO>> treeSupplier = this.fixedLazyLoadTreeSupplier.get(getTableTreeDTO.getParent_id());
      if (treeSupplier != null)
        getTableTreeDTO.setParent_id(((TableTreeVO)((List<TableTreeVO>)treeSupplier.get()).get(0)).getId()); 
    } 
    if (getTableTreeDTO.getParent_id() != null && getTableTreeDTO.getLazy_load().booleanValue()) {
      List<TableTreeVO> list = getLazyLoadTableTree(getTableTreeDTO, lzdpTableSelectConfig);
      list = handAuthorizeTableTree(getTableTreeDTO, lzdpTableSelectConfig, list);
      return list;
    } 
    List<TableTreeVO> tableTreeList = new LinkedList<>();
    if (getTableTreeDTO.getParent_id() == null) {
      if (lzdpTableSelectConfig.getEnabledPlat().contains("Collection") || lzdpTableSelectConfig.getSpatialEnabledPlat().contains("Collection")) {
        tableTreeList.add(getCollectionTableTree(getTableTreeDTO, lzdpTableSelectConfig.getEnabledPlat(), false, false, lzdpTableSelectConfig.getSpatialEnabledPlat()));
        if (isPlatHistoryEnabled(Boolean.valueOf(lzdpConfig.getLzdp().getTableSelectPlatCollection().getDataTable().getAuth().isEnableHistory()), "Collection"))
          tableTreeList.add(getCollectionTableTree(getTableTreeDTO, lzdpTableSelectConfig.getEnabledPlat(), true, false, lzdpTableSelectConfig.getSpatialEnabledPlat())); 
      } 
      if (lzdpTableSelectConfig.getEnabledPlat().contains("Manage") || lzdpTableSelectConfig.getSpatialEnabledPlat().contains("Manage")) {
        tableTreeList.add(getManageTableTree(getTableTreeDTO, lzdpTableSelectConfig.getEnabledPlat(), false, false, lzdpTableSelectConfig.getSpatialEnabledPlat()));
        if (isPlatHistoryEnabled(Boolean.valueOf(lzdpConfig.getLzdp().getTableSelectPlatManage().getDataTable().getAuth().isEnableHistory()), "Manage"))
          tableTreeList.add(getManageTableTree(getTableTreeDTO, lzdpTableSelectConfig.getEnabledPlat(), true, false, lzdpTableSelectConfig.getSpatialEnabledPlat())); 
      } 
      if (lzdpTableSelectConfig.getEnabledPlat().contains("Apply") || lzdpTableSelectConfig.getSpatialEnabledPlat().contains("Apply")) {
        getTableTreeDTO.setDirectoryType(getDirectoryType(lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth().isEnableHistory(), false, "Apply", lzdpTableSelectConfig.getEnabledPlat(), lzdpTableSelectConfig.getSpatialEnabledPlat()));
        ResultEntity<List<TableTreeVO>> applyResult = getApplyListResultEntity(getTableTreeDTO, new ResultEntity());
        if (applyResult.getCode().intValue() == 0 && !lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth().isEnableHistory()) {
          tableTreeList.addAll((Collection<? extends TableTreeVO>)applyResult.getObj());
        } else if (applyResult.getCode().intValue() == 0 && lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth().isEnableHistory()) {
          getApplyPlatData(getTableTreeDTO, lzdpConfig, lzdpTableSelectConfig, tableTreeList, applyResult);
        } 
      } 
    } else {
      String platParam = getTableTreeDTO.getParent_id().split("_")[0];
      boolean isHistory = platParam.contains("-History");
      String platCode = isHistory ? platParam.split("-History")[0] : platParam;
      if ("Collection".equals(platCode)) {
        tableTreeList.add(getCollectionTableTree(getTableTreeDTO, lzdpTableSelectConfig.getEnabledPlat(), isHistory, false, lzdpTableSelectConfig.getSpatialEnabledPlat()));
      } else if ("Manage".equals(platCode)) {
        tableTreeList.add(getManageTableTree(getTableTreeDTO, lzdpTableSelectConfig.getEnabledPlat(), isHistory, false, lzdpTableSelectConfig.getSpatialEnabledPlat()));
      } else if ("Apply".equals(platCode)) {
        if (lzdpConfig.getLzdp().getTableSelectPlatApply() != null)
          getApplyPlatTree(getTableTreeDTO, lzdpTableSelectConfig, tableTreeList, isHistory); 
      } else if (platCode.contains("Indicator")) {
        if (lzdpConfig.getLzdp().getTableSelectPlatApply().isIndexAnalysis())
          getIndexAnalysisTableTree(getTableTreeDTO, tableTreeList); 
      } else {
        return new ArrayList<>();
      } 
    } 
    tableTreeList = handAuthorizeTableTree(getTableTreeDTO, lzdpTableSelectConfig, tableTreeList);
    return tableTreeList;
  }
  
  private void getApplyPlatData(GetTableTreeDTO getTableTreeDTO, LzdpConfig lzdpConfig, LzdpConfigResult lzdpTableSelectConfig, List<TableTreeVO> tableTreeList, ResultEntity<List<TableTreeVO>> applyResult) {
    getTableTreeDTO.setDirectoryType(getDirectoryType(lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth().isEnableHistory(), false, "Apply", lzdpTableSelectConfig.getEnabledPlat(), lzdpTableSelectConfig.getSpatialEnabledPlat()));
    ResultEntity<List<TableTreeVO>> applyHistoryResult = getApplyHistoryListResultEntity(getTableTreeDTO, new ResultEntity());
    if (applyHistoryResult.getCode().intValue() == 0)
      for (int i = 0; i < ((List)applyResult.getObj()).size(); i++) {
        tableTreeList.add(((List<TableTreeVO>)applyResult.getObj()).get(i));
        if (i < ((List)applyHistoryResult.getObj()).size())
          tableTreeList.add(((List<TableTreeVO>)applyHistoryResult.getObj()).get(i)); 
      }  
  }
  
  private void getApplyPlatTree(GetTableTreeDTO getTableTreeDTO, LzdpConfigResult lzdpTableSelectConfig, List<TableTreeVO> tableTreeList, boolean isHistory) {
    List<String> spatialTableSelectablePlat = lzdpTableSelectConfig.getSpatialEnabledPlat();
    boolean tableIsHistoryApply = this.lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth().isEnableHistory();
    if (this.lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase() != null)
      if (isHistory) {
        getTableTreeDTO.setDirectoryType(getDirectoryType(tableIsHistoryApply, false, "Apply", spatialTableSelectablePlat, spatialTableSelectablePlat));
        ResultEntity<List<TableTreeVO>> applyResult = getApplyHistoryListResultEntity(getTableTreeDTO, new ResultEntity());
        if (applyResult.getCode().intValue() == 0)
          tableTreeList.addAll((Collection<? extends TableTreeVO>)applyResult.getObj()); 
      } else {
        getTableTreeDTO.setDirectoryType(getDirectoryType(tableIsHistoryApply, false, "Apply", spatialTableSelectablePlat, spatialTableSelectablePlat));
        ResultEntity<List<TableTreeVO>> applyResult = getApplyListResultEntity(getTableTreeDTO, new ResultEntity());
        if (applyResult.getCode().intValue() == 0)
          tableTreeList.addAll((Collection<? extends TableTreeVO>)applyResult.getObj()); 
      }  
  }
  
  private LzdpConfigResult getLzdpTableSelectConfig() {
    LzdpConfigResult lzdpConfigResult = null;
    List<String> enabledPlat = new ArrayList<>();
    List<String> spatialEnabledPlat = new ArrayList<>();
    List<String> applyPlatDatabaseName = new ArrayList<>();
    LzdpConfig.PlatformConfig lzdp = this.lzdpConfig.getLzdp();
    if (lzdp != null) {
      lzdpConfigResult = new LzdpConfigResult();
      if (lzdp.getTableSelectPlatManage() != null)
        lzdpConfigResult = getLzdpTableSelectConfigByPlatform(lzdpConfigResult, lzdp, "Manage", enabledPlat, spatialEnabledPlat, applyPlatDatabaseName); 
      if (lzdp.getTableSelectPlatCollection() != null)
        lzdpConfigResult = getLzdpTableSelectConfigByPlatform(lzdpConfigResult, lzdp, "Collection", enabledPlat, spatialEnabledPlat, applyPlatDatabaseName); 
      if (lzdp.getTableSelectPlatApply() != null)
        lzdpConfigResult = getLzdpTableSelectConfigByPlatform(lzdpConfigResult, lzdp, "Apply", enabledPlat, spatialEnabledPlat, applyPlatDatabaseName); 
    } 
    return lzdpConfigResult;
  }
  
  private LzdpConfigResult getLzdpTableSelectConfigByPlatform(LzdpConfigResult lzdpConfigResult, LzdpConfig.PlatformConfig lzdp, String platCode, List<String> enabledPlat, List<String> spatialEnabledPlat, List<String> applyPlatDatabaseName) {
    LzdpConfig.PlatformConfig.AuthConfig manageAuthConfig, collectionAuthConfig;
    switch (platCode) {
      case "Manage":
        manageAuthConfig = this.lzdpConfig.getLzdp().getTableSelectPlatManage().getDataTable().getAuth();
        getDatabaseAuth(manageAuthConfig, enabledPlat, "Manage", lzdp.getTableSelectPlatManage(), spatialEnabledPlat, applyPlatDatabaseName, lzdpConfigResult);
        break;
      case "Collection":
        collectionAuthConfig = lzdp.getTableSelectPlatCollection().getDataTable().getAuth();
        getDatabaseAuth(collectionAuthConfig, enabledPlat, "Collection", lzdp.getTableSelectPlatCollection(), spatialEnabledPlat, applyPlatDatabaseName, lzdpConfigResult);
        break;
      case "Apply":
        if (lzdp.getTableSelectPlatApply().getSpecialDatabase() != null) {
          LzdpConfig.PlatformConfig.AuthConfig aapplyAthConfig = lzdp.getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth();
          getDatabaseAuth(aapplyAthConfig, enabledPlat, "Apply", lzdp.getTableSelectPlatApply().getSpecialDatabase(), spatialEnabledPlat, applyPlatDatabaseName, lzdpConfigResult);
        } 
        if (lzdp.getTableSelectPlatApply().isIndexAnalysis()) {
          if (!enabledPlat.contains("Apply"))
            enabledPlat.add("Apply"); 
          applyPlatDatabaseName.add("index_analysis");
        } 
        break;
    } 
    lzdpConfigResult.setEnabledPlat(enabledPlat);
    lzdpConfigResult.setSpatialEnabledPlat(spatialEnabledPlat);
    return lzdpConfigResult;
  }
  
  private static void getDatabaseAuth(LzdpConfig.PlatformConfig.AuthConfig platAuthConfig, List<String> enabledPlat, String platCode, LzdpConfig.PlatformConfig.TableConfig lzdp, List<String> spatialEnabledPlat, List<String> applyPlatDatabaseName, LzdpConfigResult lzdpConfigResult) {
    if (platAuthConfig.isEnableTable()) {
      enabledPlat.add(platCode);
      if ("Apply".equals(platCode))
        applyPlatDatabaseName.add("special_database"); 
    } 
    if (lzdp.isSpatialTable())
      spatialEnabledPlat.add(platCode); 
  }
  
  private List<TableTreeVO> getIndexAnalysisTableTree(GetTableTreeDTO getTableTreeDTO, List<TableTreeVO> tableTreeList) {
    ResultEntity<List<TableTreeVO>> applyHistoryResult = null;
    try {
      applyHistoryResult = this.indicatorClient.getTables(getTableTreeDTO);
      CommonLogHelper.consoleInfo("调用参数：" + JSON.toJSONString(getTableTreeDTO) + "; 返回值：" + applyHistoryResult.getObj() + " ;", DCConst.ServerClientType.RESOURCE);
    } catch (Exception e) {
      CommonLogHelper.systemError(ExceptionUtil.getStackTraceMsg(e), "远程调用查询应用平台指标分析库信息接口失败:" + getTableTreeDTO, null, null);
    } 
    if (applyHistoryResult != null && applyHistoryResult.getCode().equals(DCConst.FALSE))
      for (int i = 0; i < ((List)applyHistoryResult.getObj()).size(); i++)
        tableTreeList.add(((List<TableTreeVO>)applyHistoryResult.getObj()).get(i));  
    return tableTreeList;
  }
  
  private List<TableTreeVO> handAuthorizeTableTree(GetTableTreeDTO getTableTreeDTO, LzdpConfigResult lzdpTableSelectConfig, List<TableTreeVO> tableTreeList) {
    List<String> spatialTableSelectablePlat = lzdpTableSelectConfig.getSpatialEnabledPlat();
    if (lzdpTableSelectConfig.getEnabledPlat().contains("Apply") || spatialTableSelectablePlat.contains("Apply"))
      tableTreeList = handAuthorizeData(getTableTreeDTO, tableTreeList); 
    return tableTreeList;
  }
  
  private List<TableTreeVO> handAuthorizeData(GetTableTreeDTO getTableTreeDTO, List<TableTreeVO> tableTreeList) {
    GetDataAuthorizeInfoDTO dataAuthorizeInfoDTO = new GetDataAuthorizeInfoDTO();
    dataAuthorizeInfoDTO.setSystemCode("DataCenter");
    dataAuthorizeInfoDTO.setAuthType("special");
    dataAuthorizeInfoDTO.setIsDynamicAuth(0);
    dataAuthorizeInfoDTO.setUserId(Long.valueOf(Long.parseLong(getTableTreeDTO.getUser_id())));
    dataAuthorizeInfoDTO.setOrganizationId(Long.valueOf(Long.parseLong(getTableTreeDTO.getOrganization_id())));
    ResultEntity<GetDataAuthorizeInfoVO> dataAuthorizeResult = this.coreClient.getDataAuthorizeInfo(dataAuthorizeInfoDTO, (String)WorkerId.getNextId(String.class));
    List<TableTreeVO> newTableTreeList = new ArrayList<>();
    if (dataAuthorizeResult.getCode().intValue() == 0) {
      List<DataAuthorizeItemFunInfoVO> authorizeDataInfoList = ((GetDataAuthorizeInfoVO)dataAuthorizeResult.getObj()).getAuthorizeDataInfoList();
      if (CollectionUtils.isEmpty(authorizeDataInfoList)) {
        for (TableTreeVO item : tableTreeList) {
          if (!item.getId().contains("Apply"))
            newTableTreeList.add(item); 
        } 
        return newTableTreeList;
      } 
      List<String> authItemIdList = (List<String>)authorizeDataInfoList.stream().map(DataAuthorizeItemFunInfoVO::getAuthItemId).collect(Collectors.toList());
      for (TableTreeVO item : tableTreeList) {
        if (!item.getId().contains("Apply")) {
          newTableTreeList.add(item);
          continue;
        } 
        for (String authItemId : authItemIdList) {
          if (item.getId().contains(authItemId))
            newTableTreeList.add(item); 
        } 
      } 
      return newTableTreeList;
    } 
    return tableTreeList;
  }
  
  private ResultEntity<List<TableTreeVO>> getApplyHistoryListResultEntity(GetTableTreeDTO getTableTreeDTO, ResultEntity<List<TableTreeVO>> applyHistoryResult) {
    ResultEntity<List<TableTreeVO>> resultEntity = new ResultEntity();
    try {
      applyHistoryResult = this.dataApplyClient.getDirectoryTreeHistoryData(getTableTreeDTO, WorkerId.getNextId());
    } catch (Exception e) {
      resultEntity.setCode(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_APPLY_HISTORY_TABLE_TREE_FAILED.getCode()));
      resultEntity.setMsg(StatusCodeEnum.DATA_RESOURCE_GET_APPLY_HISTORY_TABLE_TREE_FAILED.getMessage());
      LogHelper.error("远程调用dataApplyClient服务失败，具体信息：" + ExceptionUtil.getStackTraceMsg(e));
      return resultEntity;
    } 
    return applyHistoryResult;
  }
  
  private ResultEntity<List<TableTreeVO>> getApplyListResultEntity(GetTableTreeDTO getTableTreeDTO, ResultEntity<List<TableTreeVO>> applyHistoryResult) {
    ResultEntity<List<TableTreeVO>> resultEntity = new ResultEntity();
    try {
      applyHistoryResult = this.dataApplyClient.getDirectoryTreeData(getTableTreeDTO, WorkerId.getNextId());
    } catch (Exception e) {
      resultEntity.setCode(Integer.valueOf(StatusCodeEnum.DATA_RESOURCE_GET_APPLY_TABLE_TREE_FAILED.getCode()));
      resultEntity.setMsg(StatusCodeEnum.DATA_RESOURCE_GET_APPLY_TABLE_TREE_FAILED.getMessage());
      LogHelper.error("远程调用dataApplyClient服务失败，具体信息：" + ExceptionUtil.getStackTraceMsg(e));
      return resultEntity;
    } 
    return applyHistoryResult;
  }
  
  public ResultEntity<TableVO> getTableStruct(GetTableDTO getTableDTO) {
    TableVO tableVO = new TableVO();
    String tableId = getTableDTO.getTable_id();
    String[] array = tableId.split("_");
    if (array == null || array.length == 0)
      return ResultEntity.errorMessage(Integer.valueOf(-1), "表id【" + tableId + "】格式错误！"); 
    String platCode = array[0];
    boolean isHistory = platCode.contains("-History");
    if (isHistory)
      platCode = platCode.substring(0, platCode.lastIndexOf("-History")); 
    if (platCode.equalsIgnoreCase("Collection") || platCode.equalsIgnoreCase("Manage")) {
      String directoryId = array[1];
      getTableStructByPlatCode(tableVO, tableId, directoryId, platCode);
      if (isHistory)
        tableVO.setTable_en_name(tableVO.getTable_en_name() + "_history"); 
    } else {
      if (platCode.equalsIgnoreCase("Apply")) {
        if (isHistory)
          return this.dataApplyClient.getHistoryTableStructure(getTableDTO, WorkerId.getNextId()); 
        return this.dataApplyClient.getTableStructure(getTableDTO, WorkerId.getNextId());
      } 
      if (platCode.equalsIgnoreCase("Indicator")) {
        ResultEntity<TableVO> tableInfo = null;
        try {
          tableInfo = this.indicatorClient.getTableInfo(getTableDTO);
          CommonLogHelper.consoleInfo("远程调用指标分析库根据tableId获取表结构,入参：" + JSON.toJSONString(getTableDTO) + ",返回值：" + JSON.toJSONString(tableInfo.getObj()), DCConst.ServerClientType.RESOURCE);
        } catch (Exception e) {
          CommonLogHelper.systemError(ExceptionUtil.getStackTraceMsg(e), "远程调用获取应用平台指标分析库表信息接口失败:" + tableInfo, null, null);
        } 
        CommonLogHelper.consoleInfo("临时记录日志文件:" + JSON.toJSONString(tableInfo.getObj()), DCConst.ServerClientType.RESOURCE);
        return tableInfo;
      } 
    } 
    return ResultEntity.successMessage(tableVO);
  }
  
  public ResultEntity<List<Map<String, Object>>> getData(GetDataDTO dataDTO) {
    List<Map<String, Object>> dataList = new ArrayList<>();
    String tableId = dataDTO.getTable_id();
    String[] array = tableId.split("_");
    if (array == null || array.length == 0)
      return ResultEntity.errorMessage(Integer.valueOf(-1), "表id【" + tableId + "】格式错误！"); 
    String platCode = array[0];
    boolean isHistory = platCode.contains("-History");
    if (isHistory)
      platCode = platCode.substring(0, platCode.lastIndexOf("-History")); 
    if (platCode.equalsIgnoreCase("Collection") || platCode.equalsIgnoreCase("Manage")) {
      String directoryId = array[1];
      ResultEntity<List<Map<String, Object>>> result = ((IDataResource)ServiceUtil.getDataResourceManager(platCode, IDataResource.class)).getQueryByDirectoryIdAndSql(Long.valueOf(Long.parseLong(directoryId)), platCode, dataDTO.getExecute_sql(), Boolean.valueOf(isHistory));
      if (result.getCode().equals(Integer.valueOf(0)) && result.getObj() != null) {
        dataList = (List<Map<String, Object>>)result.getObj();
      } else {
        return result;
      } 
    } else if (platCode.equalsIgnoreCase("Apply")) {
      ResultEntity<List<Map<String, Object>>> result = new ResultEntity();
      if (!isHistory) {
        result = this.dataApplyClient.getTableData(dataDTO, WorkerId.getNextId());
      } else {
        result = this.dataApplyClient.getHistoryTableData(dataDTO, WorkerId.getNextId());
      } 
      if (result.getCode().equals(Integer.valueOf(0)) && result.getObj() != null) {
        dataList = (List<Map<String, Object>>)result.getObj();
      } else {
        return result;
      } 
    } else if (platCode.equalsIgnoreCase("Indicator")) {
      ResultEntity<List<Map<String, Object>>> result = null;
      try {
        result = this.indicatorClient.getData(dataDTO);
        CommonLogHelper.consoleInfo("查询指标分析表数据，参数" + JSON.toJSONString(dataDTO) + ",返回值：" + result.getObj(), DCConst.ServerClientType.RESOURCE);
      } catch (Exception e) {
        CommonLogHelper.systemError(ExceptionUtil.getStackTraceMsg(e), "远程调用获取应用平台指标分析库表数据接口失败:" + dataDTO, null, null);
      } 
      if (result.getCode().equals(Integer.valueOf(0)) && result.getObj() != null) {
        dataList = (List<Map<String, Object>>)result.getObj();
      } else {
        return result;
      } 
    } 
    dataList = handDataDesensitize(dataList, dataDTO, dataDTO.getTokenId());
    return ResultEntity.successMessage(dataList);
  }
  
  public ResultEntity<Boolean> operateLog(OperateLogDTO operateLogDTO) {
    return this.dataApplyClient.writeOperateLog(operateLogDTO, WorkerId.getNextId());
  }
  
  public ResultEntity<List<List<Object>>> dataDesensitize(DataDesensitizeDTO dataDesensitizeDTO) {
    List<List<Object>> data = dataDesensitizeDTO.getData();
    List<FieldVO> fields = dataDesensitizeDTO.getFields();
    List<DataDesensitizePO> desensitizePOS = getDataDesensitizePOFromFields(fields);
    Map<Integer, DesensitseRule> desensitseRuleMap = new HashMap<>();
    for (int i = 0; i < desensitizePOS.size(); i++) {
      DesensitseRule desensitseRule = new DesensitseRule();
      BeanUtils.copyProperties(desensitizePOS.get(i), desensitseRule);
      desensitseRuleMap.put(Integer.valueOf(i), desensitseRule);
    } 
    List<List<Object>> result = new ArrayList<>();
    for (List<Object> row : data) {
      List<Object> newRow = new ArrayList();
      for (int j = 0; j < row.size(); j++) {
        if (row.get(j) != null && desensitseRuleMap.get(Integer.valueOf(j)) != null) {
          String val = DesensitizeUtil.commonDisplay(row.get(j).toString(), desensitseRuleMap.get(Integer.valueOf(j)));
          newRow.add(val);
        } else {
          newRow.add(row.get(j));
        } 
      } 
      result.add(newRow);
    } 
    return ResultEntity.successMessage(result);
  }
  
  public ResultEntity<String> getLZDPApiData(GetLZDPDataDTO lzdpDataDTO, String tokenId) {
    String result = null;
    String api = (String)DCConst.LZDP_API.get(lzdpDataDTO.getCode());
    String url = this.lzdpApi + "/" + api;
    if (CoreConst.RequestType.GET_REQUEST.equalsIgnoreCase(lzdpDataDTO.getRequestType())) {
      if (lzdpDataDTO.getPathParam() != null) {
        Map<String, Object> getPathParam = (Map<String, Object>)lzdpDataDTO.getPathParam();
        if (!getPathParam.isEmpty())
          for (String key : getPathParam.keySet())
            url = url.replace("{" + key + "}", (new StringBuilder()).append(getPathParam.get(key)).append("").toString());  
      } 
      Map<String, Object> headers = new HashMap<>();
      headers.put("mcode", "DataCenter");
      headers.put("sessionId", lzdpDataDTO.getSessionId());
      headers.put("token", tokenId + "#" + System.currentTimeMillis());
      result = HttpClientUtil.get(url, headers);
    } else if (CoreConst.RequestType.POST_REQUEST.equalsIgnoreCase(lzdpDataDTO.getRequestType())) {
      Object<Object, Object> postParam;
      if (lzdpDataDTO.getPathParam() != null) {
        Map<String, Object> getPathParam = (Map<String, Object>)lzdpDataDTO.getPathParam();
        if (!getPathParam.isEmpty())
          for (String key : getPathParam.keySet())
            url = url.replace("{" + key + "}", (new StringBuilder()).append(getPathParam.get(key)).append("").toString());  
      } 
      if (lzdpDataDTO.getRequestParam() != null) {
        postParam = (Object<Object, Object>)lzdpDataDTO.getRequestParam();
      } else {
        postParam = (Object<Object, Object>)new HashMap<>();
      } 
      Map<String, Object> headers = new HashMap<>();
      headers.put("mcode", "DataCenter");
      headers.put("sessionId", lzdpDataDTO.getSessionId());
      headers.put("token", tokenId + "#" + System.currentTimeMillis());
      result = HttpClientUtil.post(url, JSON.toJSONString(postParam), headers).toString();
    } 
    return (ResultEntity<String>)JSON.parseObject(result, ResultEntity.class);
  }
  
  private List<Map<String, Object>> handDataDesensitize(List<Map<String, Object>> dataList, GetDataDTO dataDTO, String tokenId) {
    if (dataDTO.getDesensitse_field() != null && !dataDTO.getDesensitse_field().isEmpty()) {
      List<DataDesensitizePO> desensitizePOS = getDataDesensitizePOFromFields(dataDTO.getDesensitse_field());
      List<MetadataEntityInfoItemPO> infoItemsByEntity = null;
      switch (((DataDesensitizePO)desensitizePOS.get(0)).getPlatCode().intValue()) {
        case 0:
          infoItemsByEntity = ((IInfoItem)ServiceUtil.getInfoItemManager("Collection", IInfoItem.class)).getEntityInfoItemsByEntityId(((DataDesensitizePO)desensitizePOS.get(0)).getTableId(), "Collection", dataDTO.getIsResources(), tokenId);
          break;
        case 1:
          infoItemsByEntity = ((IInfoItem)ServiceUtil.getInfoItemManager("Manage", IInfoItem.class)).getEntityInfoItemsByEntityId(((DataDesensitizePO)desensitizePOS.get(0)).getTableId(), "Manage", dataDTO.getIsResources(), tokenId);
          break;
        case 2:
          infoItemsByEntity = ((IInfoItem)ServiceUtil.getInfoItemManager("Apply", IInfoItem.class)).getEntityInfoItemsByEntityId(((DataDesensitizePO)desensitizePOS.get(0)).getTableId(), "Apply", dataDTO.getIsResources(), tokenId);
          break;
        case 3:
          infoItemsByEntity = ((IInfoItem)ServiceUtil.getInfoItemManager("Standard", IInfoItem.class)).getEntityInfoItemsByEntityId(((DataDesensitizePO)desensitizePOS.get(0)).getTableId(), "Standard", dataDTO.getIsResources(), tokenId);
          break;
      } 
      List<DesensitseRule> desensitseRuleList = new ArrayList<>();
      for (int i = 0; i < desensitizePOS.size(); i++) {
        DesensitseRule desensitseRule = new DesensitseRule();
        BeanUtils.copyProperties(desensitizePOS.get(i), desensitseRule);
        desensitseRule.setFileldName(getFiledName(infoItemsByEntity, ((DataDesensitizePO)desensitizePOS.get(i)).getFieldId()));
        desensitseRuleList.add(desensitseRule);
      } 
      dataList = DesensitizeUtil.commonDesensitse(desensitseRuleList, dataList);
    } 
    return dataList;
  }
  
  public String getFiledName(List<MetadataEntityInfoItemPO> infoItemsByEntity, Long filedId) {
    for (MetadataEntityInfoItemPO metadataEntityInfoItemPO : infoItemsByEntity) {
      if (metadataEntityInfoItemPO.getInfoItemId().equals(filedId))
        return metadataEntityInfoItemPO.getDataItemName(); 
    } 
    return null;
  }
  
  private List<DataDesensitizePO> getDataDesensitizePOFromFields(List<FieldVO> fields) {
    List<Long> fieldIds = new ArrayList<>();
    for (FieldVO fieldVO : fields)
      fieldIds.add(Long.valueOf(fieldVO.getField_id())); 
    return this.iDataDesensitizeDao.checkDataDesensitize(fieldIds);
  }
  
  private List<TableTreeVO> getLazyLoadTableTree(GetTableTreeDTO getTableTreeDTO, LzdpConfigResult lzdpTableSelectConfig) {
    String platParam = getTableTreeDTO.getParent_id().split("_")[0];
    boolean isHistory = platParam.contains("-History");
    String platCode = isHistory ? platParam.split("-History")[0] : platParam;
    switch (getTableTreeDTO.getParent_id()) {
      case "Collection_100000000000000000":
        getTableTreeDTO.setParent_id(null);
        if (this.lzdpConfig.getLzdp().getTableSelectPlatCollection() != null)
          return getCollectionStepByStepTableTree(getTableTreeDTO, false, false, "Collection", lzdpTableSelectConfig); 
      case "Collection-History_100000000000000000":
        getTableTreeDTO.setParent_id(null);
        return getCollectionStepByStepTableTree(getTableTreeDTO, true, false, "Collection", lzdpTableSelectConfig);
      case "Manage_100000000000000000":
        getTableTreeDTO.setParent_id(null);
        return getManageStepByStepTableTree(getTableTreeDTO, false, Boolean.valueOf(false), "Manage", lzdpTableSelectConfig);
      case "Manage-History_100000000000000000":
        getTableTreeDTO.setParent_id(null);
        return getManageStepByStepTableTree(getTableTreeDTO, true, Boolean.valueOf(false), "Manage", lzdpTableSelectConfig);
    } 
    if (getTableTreeDTO.getParent_id().contains("Indicator")) {
      List<TableTreeVO> tableTreeList = new ArrayList<>();
      return getIndexAnalysisTableTree(getTableTreeDTO, tableTreeList);
    } 
    if (getTableTreeDTO.getParent_id().contains("Apply"))
      return getSpecialDatabaseTree(getTableTreeDTO, lzdpTableSelectConfig, lzdpTableSelectConfig.getSpatialEnabledPlat(), lzdpTableSelectConfig.getEnabledPlat(), isHistory); 
    String parentId = getTableTreeDTO.getParent_id();
    String[] array = parentId.split("_");
    String id = array[1];
    getTableTreeDTO.setParent_id(id);
    if (platCode.equals("Collection"))
      return getCollectionStepByStepTableTree(getTableTreeDTO, isHistory, false, platCode, lzdpTableSelectConfig); 
    if (platCode.equals("Manage"))
      return getManageStepByStepTableTree(getTableTreeDTO, isHistory, Boolean.valueOf(false), platCode, lzdpTableSelectConfig); 
    if (platCode.equals("Apply"))
      return null; 
    return new ArrayList<>();
  }
  
  private List<TableTreeVO> getSpecialDatabaseTree(GetTableTreeDTO getTableTreeDTO, LzdpConfigResult lzdpTableSelectConfig, List<String> spatialTableSelectablePlat, List<String> enabledPlat, boolean isHistory) {
    ResultEntity<List<TableTreeVO>> applyResult;
    Integer directoryType = getDirectoryType(isHistory, false, "Apply", enabledPlat, spatialTableSelectablePlat);
    getTableTreeDTO.setDirectoryType(directoryType);
    try {
      if (!isHistory) {
        applyResult = this.dataApplyClient.getDirectoryTreeData(getTableTreeDTO, WorkerId.getNextId());
      } else {
        applyResult = this.dataApplyClient.getDirectoryTreeHistoryData(getTableTreeDTO, WorkerId.getNextId());
      } 
    } catch (Exception e) {
      LogHelper.error("远程调用dataApplyClient服务失败，具体信息：" + ExceptionUtil.getStackTraceMsg(e));
      return new ArrayList<>();
    } 
    return (applyResult.getCode().intValue() == 0) ? (List<TableTreeVO>)applyResult.getObj() : new ArrayList<>();
  }
  
  private List<TableTreeVO> getPlatTree(GetTableTreeDTO getTableTreeDTO, LzdpConfigResult lzdpTableSelectConfig) {
    List<TableTreeVO> tableTreeList = new LinkedList<>();
    if (this.lzdpConfig.getLzdp().getTableSelectPlatCollection() != null) {
      if (this.lzdpConfig.getLzdp().getTableSelectPlatCollection().getDataTable().getAuth().isEnableTable())
        tableTreeList.add(collectionPlatTree()); 
      if (isPlatHistoryEnabled(Boolean.valueOf(this.lzdpConfig.getLzdp().getTableSelectPlatCollection().getDataTable().getAuth().isEnableHistory()), "Collection"))
        tableTreeList.add(collectionPlatHistoryTree()); 
    } 
    if (this.lzdpConfig.getLzdp().getTableSelectPlatManage() != null) {
      if (this.lzdpConfig.getLzdp().getTableSelectPlatManage().getDataTable().getAuth().isEnableTable())
        tableTreeList.add(managePlatTree()); 
      if (isPlatHistoryEnabled(Boolean.valueOf(this.lzdpConfig.getLzdp().getTableSelectPlatManage().getDataTable().getAuth().isEnableHistory()), "Manage"))
        tableTreeList.add(managePlatHistoryTree()); 
    } 
    if (this.lzdpConfig.getLzdp().getTableSelectPlatApply() != null) {
      if (this.lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase() != null)
        getApplyPlatformSpecialDatabaseTree(getTableTreeDTO, tableTreeList); 
      if (this.lzdpConfig.getLzdp().getTableSelectPlatApply().isIndexAnalysis())
        getIndexAnalysisTableTree(getTableTreeDTO, tableTreeList); 
    } 
    return tableTreeList;
  }
  
  private void getApplyPlatformSpecialDatabaseTree(GetTableTreeDTO getTableTreeDTO, List<TableTreeVO> tableTreeList) {
    getTableTreeDTO.setEnableSpatialTable(Boolean.valueOf(this.lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().isSpatialTable()));
    ResultEntity<List<TableTreeVO>> applyResult = this.dataApplyClient.getDirectoryTreeData(getTableTreeDTO, WorkerId.getNextId());
    if (applyResult.getCode().intValue() == 0 && !this.lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().getDataTable().getAuth().isEnableHistory()) {
      tableTreeList.addAll((Collection<? extends TableTreeVO>)applyResult.getObj());
    } else if (applyResult.getCode().intValue() == 0) {
      getTableTreeDTO.setEnableSpatialTable(Boolean.valueOf(this.lzdpConfig.getLzdp().getTableSelectPlatApply().getSpecialDatabase().isSpatialTable()));
      ResultEntity<List<TableTreeVO>> applyHistoryResult = this.dataApplyClient.getDirectoryTreeHistoryData(getTableTreeDTO, WorkerId.getNextId());
      if (applyHistoryResult.getCode().intValue() == 0)
        for (int i = 0; i < ((List)applyResult.getObj()).size(); i++) {
          tableTreeList.add(((List<TableTreeVO>)applyResult.getObj()).get(i));
          if (i < ((List)applyHistoryResult.getObj()).size())
            tableTreeList.add(((List<TableTreeVO>)applyHistoryResult.getObj()).get(i)); 
        }  
    } 
  }
  
  private TableTreeVO collectionPlatTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Collection");
    tableTreeVO.setParent_id(null);
    tableTreeVO.setName("采集库");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO collectionPlatHistoryTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Collection-History");
    tableTreeVO.setParent_id(null);
    tableTreeVO.setName("采集库_拉链表");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO collectionDBTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Collection_100000000000000000");
    tableTreeVO.setParent_id("Collection");
    tableTreeVO.setName("采集数据库");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO collectionDBHistoryTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Collection-History_100000000000000000");
    tableTreeVO.setParent_id("Collection-History");
    tableTreeVO.setName("采集数据库");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO managePlatTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage");
    tableTreeVO.setParent_id(null);
    tableTreeVO.setName("管理库");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO managePlatHistoryTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage-History");
    tableTreeVO.setParent_id(null);
    tableTreeVO.setName("管理库_拉链表");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO manageDBTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage_100000000000000000");
    tableTreeVO.setParent_id("Manage");
    tableTreeVO.setName("数据管理目录");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO indicatorDBTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Indicator_100000000000000000");
    tableTreeVO.setParent_id("Indicator");
    tableTreeVO.setName("指标分析库");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO manageDBHistoryTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage-History_100000000000000000");
    tableTreeVO.setParent_id("Manage-History");
    tableTreeVO.setName("数据管理目录");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO manageTableTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage_210000000000000000");
    tableTreeVO.setParent_id("Manage_100000000000000000");
    tableTreeVO.setName("数据表管理");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO manageTableHistoryTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage-History_210000000000000000");
    tableTreeVO.setParent_id("Manage-History_100000000000000000");
    tableTreeVO.setName("数据表管理");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO manageViewTableTree() {
    TableTreeVO tableTreeVO = new TableTreeVO();
    tableTreeVO.setId("Manage_220000000000000000");
    tableTreeVO.setParent_id("Manage_100000000000000000");
    tableTreeVO.setName("视图管理");
    tableTreeVO.setType(Integer.valueOf(0));
    tableTreeVO.setChildren(new ArrayList());
    return tableTreeVO;
  }
  
  private TableTreeVO getCollectionTableTree(GetTableTreeDTO getTableTreeDTO, List<String> enabledPlat, boolean isHistory, boolean spatialTableIsHistory, List<String> spatialTableSelectablePlat) {
    TableTreeVO tableTreeVO = isHistory ? collectionPlatHistoryTree() : collectionPlatTree();
    List<TableTreeVO> tableTreeList = new ArrayList<>();
    GetDirectoryTreeDataDTO getDirectoryTreeDataDTO = new GetDirectoryTreeDataDTO();
    if (getTableTreeDTO.getLazy_load().booleanValue()) {
      getDirectoryTreeDataDTO.setDirectoryId(Long.valueOf(Long.parseLong(getTableTreeDTO.getParent_id())));
      getDirectoryTreeDataDTO.setIsLazyLoading(null);
    } else {
      getDirectoryTreeDataDTO.setDirectoryId(null);
      getDirectoryTreeDataDTO.setIsLazyLoading(Integer.valueOf(0));
    } 
    getDirectoryTreeDataDTO.setDirectoryType(getDirectoryType(isHistory, spatialTableIsHistory, "Collection", enabledPlat, spatialTableSelectablePlat));
    getDirectoryTreeDataDTO.setDataCategory(Integer.valueOf(0));
    getDirectoryTreeDataDTO.setDataResourceCategory(DCConst.DataResourceCategory.DATA);
    ResultEntity<List<DirectoryTreeVO>> resultEntity = new ResultEntity();
    if (getTableTreeDTO.getQuery() != null && !StringUtils.isEmpty(getTableTreeDTO.getQuery().getQuery_value())) {
      if (getTableTreeDTO.getQuery().getQuery_name().equals("id")) {
        String[] array = getTableTreeDTO.getQuery().getQuery_value().split("_");
        String directoryId = null;
        if (enabledPlat.contains(array[0].split("-History")[0]))
          directoryId = array[1]; 
        resultEntity = ((IDataResource)ServiceUtil.getDataResourceManager("Collection", IDataResource.class)).getDirectoryTreeData("Collection", getDirectoryTreeDataDTO, directoryId);
      } else if (getTableTreeDTO.getQuery().getQuery_name().equals("name")) {
        getDirectoryTreeDataDTO.setDirectoryName(getTableTreeDTO.getQuery().getQuery_value());
        resultEntity = ((IDataResource)ServiceUtil.getDataResourceManager("Collection", IDataResource.class)).getDirectoryTreeData("Collection", getDirectoryTreeDataDTO);
      } 
    } else {
      resultEntity = ((IDataResource)ServiceUtil.getDataResourceManager("Collection", IDataResource.class)).getDirectoryTreeData("Collection", getDirectoryTreeDataDTO);
    } 
    if (resultEntity.getCode().intValue() != 0)
      return tableTreeVO; 
    List<DirectoryTreeVO> directoryTreeVOList = (List<DirectoryTreeVO>)resultEntity.getObj();
    if (!CollectionUtils.isEmpty(directoryTreeVOList)) {
      if (isHistory) {
        tableTreeList = getRecurveTable("Collection-History", new ArrayList<>(), directoryTreeVOList, "Collection-History_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } else {
        tableTreeList = getRecurveTable("Collection", new ArrayList<>(), directoryTreeVOList, "Collection_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } 
      tableTreeVO = tableTreeList.get(0);
    } 
    return tableTreeVO;
  }
  
  private List<TableTreeVO> getCollectionStepByStepTableTree(GetTableTreeDTO getTableTreeDTO, boolean isHistory, boolean spatialTableIsHistory, String platCode, LzdpConfigResult lzdpTableSelectConfig) {
    List<TableTreeVO> tableTreeVOList = getTableTreeVOS();
    GetDirectoryTreeDataDTO getDirectoryTreeDataDTO = new GetDirectoryTreeDataDTO();
    if (getTableTreeDTO.getLazy_load().booleanValue()) {
      getDirectoryTreeDataDTO.setDirectoryId((getTableTreeDTO.getParent_id() == null) ? null : Long.valueOf(Long.parseLong(getTableTreeDTO.getParent_id())));
      getDirectoryTreeDataDTO.setIsLazyLoading(null);
    } else {
      getDirectoryTreeDataDTO.setDirectoryId(null);
      getDirectoryTreeDataDTO.setIsLazyLoading(Integer.valueOf(0));
    } 
    getDirectoryTreeDataDTO.setDirectoryType(getDirectoryType(isHistory, spatialTableIsHistory, platCode, lzdpTableSelectConfig.getEnabledPlat(), lzdpTableSelectConfig.getSpatialEnabledPlat()));
    getDirectoryTreeDataDTO.setDataCategory(Integer.valueOf(0));
    getDirectoryTreeDataDTO.setDataResourceCategory(DCConst.DataResourceCategory.DATA);
    ResultEntity<List<DirectoryTreeVO>> resultEntity = ((IDataResource)ServiceUtil.getDataResourceManager("Collection", IDataResource.class)).getDirectoryTreeData("Collection", getDirectoryTreeDataDTO);
    if (resultEntity.getCode().intValue() != 0)
      return tableTreeVOList; 
    List<DirectoryTreeVO> directoryTreeVOList = (List<DirectoryTreeVO>)resultEntity.getObj();
    if (!CollectionUtils.isEmpty(directoryTreeVOList)) {
      if (isHistory) {
        tableTreeVOList = getRecurveTable("Collection-History", new ArrayList<>(), directoryTreeVOList, "Collection-History_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } else {
        tableTreeVOList = getRecurveTable("Collection", new ArrayList<>(), directoryTreeVOList, "Collection_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } 
      CommonLogHelper.consoleInfo("逐级获取采集平台数据表树，入参" + JSON.toJSONString(getDirectoryTreeDataDTO) + "; 返回值：" + JSON.toJSONString(tableTreeVOList) + " ;", DCConst.ServerClientType.RESOURCE);
    } 
    return tableTreeVOList;
  }
  
  private static List<TableTreeVO> getTableTreeVOS() {
    List<TableTreeVO> tableTreeVOList = new ArrayList<>();
    return tableTreeVOList;
  }
  
  private Integer getDirectoryType(boolean isHistory, boolean spatialTableIsHistory, String platCode, List<String> tableSelectablePlat, List<String> enabledSpatialTablePlat) {
    Integer directoryType = null;
    if (!isHistory && spatialTableIsHistory) {
      if (tableSelectablePlat.contains(platCode) && enabledSpatialTablePlat.contains(platCode)) {
        directoryType = null;
      } else if (tableSelectablePlat.contains(platCode)) {
        directoryType = Integer.valueOf(1);
      } else if (enabledSpatialTablePlat.contains(platCode)) {
        directoryType = Integer.valueOf(3);
      } 
    } else if (!isHistory && !spatialTableIsHistory) {
      if (tableSelectablePlat.contains(platCode) && enabledSpatialTablePlat.contains(platCode)) {
        directoryType = null;
      } else if (tableSelectablePlat.contains(platCode)) {
        directoryType = Integer.valueOf(1);
      } else if (enabledSpatialTablePlat.contains(platCode)) {
        directoryType = Integer.valueOf(3);
      } 
    } else if (isHistory && spatialTableIsHistory) {
      if (tableSelectablePlat.contains(platCode) && enabledSpatialTablePlat.contains(platCode)) {
        directoryType = null;
      } else if (tableSelectablePlat.contains(platCode)) {
        directoryType = Integer.valueOf(1);
      } else if (enabledSpatialTablePlat.contains(platCode)) {
        directoryType = Integer.valueOf(3);
      } 
    } else if (isHistory && !spatialTableIsHistory) {
      if (tableSelectablePlat.contains(platCode))
        directoryType = Integer.valueOf(1); 
    } else if (!isHistory && spatialTableIsHistory && 
      enabledSpatialTablePlat.contains(platCode)) {
      directoryType = Integer.valueOf(3);
    } 
    return directoryType;
  }
  
  private TableTreeVO getManageTableTree(GetTableTreeDTO getTableTreeDTO, List<String> enabledPlat, boolean isHistory, boolean spatialTableIsHistory, List<String> spatialTableSelectablePlat) {
    TableTreeVO tableTreeVO = isHistory ? managePlatHistoryTree() : managePlatTree();
    List<TableTreeVO> tableTreeList = new ArrayList<>();
    GetDirectoryTreeDataDTO getDirectoryTreeDataDTO = new GetDirectoryTreeDataDTO();
    getDirectoryTreeDataDTO.setDirectoryType(getDirectoryType(isHistory, spatialTableIsHistory, "Manage", enabledPlat, spatialTableSelectablePlat));
    getDirectoryTreeDataDTO.setDirectoryId(null);
    getDirectoryTreeDataDTO.setIsLazyLoading(Integer.valueOf(0));
    getDirectoryTreeDataDTO.setDataCategory(Integer.valueOf(0));
    getDirectoryTreeDataDTO.setDataResourceCategory(DCConst.DataResourceCategory.DATA);
    List<String> tableSelectablePlat = enabledPlat;
    List<DirectoryTreeVO> tableDirectoryTreeVOList = new ArrayList<>();
    if (getTableTreeDTO.getQuery() != null && !StringUtils.isEmpty(getTableTreeDTO.getQuery().getQuery_value())) {
      if (getTableTreeDTO.getQuery() != null && !StringUtils.isEmpty(getTableTreeDTO.getQuery().getQuery_value()))
        if (getTableTreeDTO.getQuery().getQuery_name().equals("id")) {
          String[] array = getTableTreeDTO.getQuery().getQuery_value().split("_");
          String directoryId = null;
          if (enabledPlat.contains(array[0].split("-History")[0]))
            directoryId = array[1]; 
          tableDirectoryTreeVOList = (List<DirectoryTreeVO>)((IDataResource)ServiceUtil.getDataResourceManager("Manage", IDataResource.class)).getDirectoryTreeData("Manage", getDirectoryTreeDataDTO, directoryId).getObj();
          CommonLogHelper.consoleInfo("根据id查询指定管理库目录结构，入参：" + JSON.toJSONString(getDirectoryTreeDataDTO) + ",返回值《" + tableDirectoryTreeVOList + "》", DCConst.ServerClientType.RESOURCE);
        } else if (getTableTreeDTO.getQuery().getQuery_name().equals("name")) {
          getDirectoryTreeDataDTO.setDirectoryName(getTableTreeDTO.getQuery().getQuery_value());
          tableDirectoryTreeVOList = (List<DirectoryTreeVO>)((IDataResource)ServiceUtil.getDataResourceManager("Manage", IDataResource.class)).getDirectoryTreeData("Manage", getDirectoryTreeDataDTO).getObj();
          CommonLogHelper.consoleInfo("根据name查询指定管理库目录结构，入参：" + JSON.toJSONString(getDirectoryTreeDataDTO) + ",返回值《" + tableDirectoryTreeVOList + "》", DCConst.ServerClientType.RESOURCE);
        }  
    } else {
      tableDirectoryTreeVOList = (List<DirectoryTreeVO>)((IDataResource)ServiceUtil.getDataResourceManager("Manage", IDataResource.class)).getDirectoryTreeData("Manage", getDirectoryTreeDataDTO).getObj();
      CommonLogHelper.consoleInfo("查询管理库目录结构，入参：" + JSON.toJSONString(getDirectoryTreeDataDTO) + ",返回值《" + tableDirectoryTreeVOList + "》", DCConst.ServerClientType.RESOURCE);
    } 
    if (!CollectionUtils.isEmpty(tableDirectoryTreeVOList)) {
      List<TableTreeVO> childTableTreeVO;
      if (isHistory) {
        childTableTreeVO = getRecurveTable("Manage-History", new ArrayList<>(), tableDirectoryTreeVOList, "Manage-History_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } else {
        childTableTreeVO = getRecurveTable("Manage", new ArrayList<>(), tableDirectoryTreeVOList, "Manage_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } 
      tableTreeVO = childTableTreeVO.get(0);
    } 
    CommonLogHelper.consoleInfo("获取管理平台数据表树，返回值《" + tableDirectoryTreeVOList + "》", DCConst.ServerClientType.RESOURCE);
    return tableTreeVO;
  }
  
  private List<TableTreeVO> getManageStepByStepTableTree(GetTableTreeDTO getTableTreeDTO, boolean isHistory, Boolean spatialTableIsHistory, String platCode, LzdpConfigResult lzdpTableSelectConfig) {
    List<TableTreeVO> tableTreeList = new ArrayList<>();
    GetDirectoryTreeDataDTO getDirectoryTreeDataDTO = new GetDirectoryTreeDataDTO();
    if (getTableTreeDTO.getLazy_load().booleanValue()) {
      getDirectoryTreeDataDTO.setDirectoryId((getTableTreeDTO.getParent_id() == null) ? null : Long.valueOf(Long.parseLong(getTableTreeDTO.getParent_id())));
      getDirectoryTreeDataDTO.setIsLazyLoading(null);
    } else {
      getDirectoryTreeDataDTO.setDirectoryId(null);
      getDirectoryTreeDataDTO.setIsLazyLoading(Integer.valueOf(0));
    } 
    getDirectoryTreeDataDTO.setDirectoryType(getDirectoryType(isHistory, spatialTableIsHistory.booleanValue(), platCode, lzdpTableSelectConfig.getEnabledPlat(), lzdpTableSelectConfig.getSpatialEnabledPlat()));
    getDirectoryTreeDataDTO.setDataCategory(Integer.valueOf(0));
    List<DirectoryTreeVO> tableDirectoryTreeVOList = (List<DirectoryTreeVO>)((IDataResource)ServiceUtil.getDataResourceManager("Manage", IDataResource.class)).getDirectoryTreeData("Manage", getDirectoryTreeDataDTO).getObj();
    if (!CollectionUtils.isEmpty(tableDirectoryTreeVOList)) {
      if (isHistory) {
        tableTreeList = getRecurveTable("Manage-History", new ArrayList<>(), tableDirectoryTreeVOList, "Manage-History_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } else {
        tableTreeList = getRecurveTable("Manage", new ArrayList<>(), tableDirectoryTreeVOList, "Manage_100000000000000000", getTableTreeDTO.getInclude_field_info());
      } 
      CommonLogHelper.consoleInfo("逐级获取管理平台数据表树：" + JSON.toJSONString(getDirectoryTreeDataDTO) + "; 返回值：" + JSON.toJSONString(tableDirectoryTreeVOList) + " ;", DCConst.ServerClientType.RESOURCE);
    } 
    return tableTreeList;
  }
  
  private List<TableTreeVO> getRecurveTable(String platCode, List<TableTreeVO> tableTreeList, List<DirectoryTreeVO> directoryTreeList, String parentId, Boolean includeFieldInfo) {
    if (!CollectionUtils.isEmpty(directoryTreeList))
      for (DirectoryTreeVO directoryTreeVO : directoryTreeList) {
        TableTreeVO dcTableTree = new TableTreeVO();
        dcTableTree.setId(platCode + "_" + directoryTreeVO.getDirectoryId().toString());
        dcTableTree.setParent_id((directoryTreeVO.getParentDirectoryId() == null) ? null : (platCode + "_" + directoryTreeVO.getParentDirectoryId().toString()));
        dcTableTree.setType(directoryTreeVO.getDirectoryType());
        dcTableTree.setName(directoryTreeVO.getDirectoryName());
        if (includeFieldInfo.booleanValue() && (directoryTreeVO.getDirectoryType().intValue() == 1 || directoryTreeVO.getDirectoryType().intValue() == 2)) {
          GetTableDTO tableDTO = new GetTableDTO();
          tableDTO.setTable_id(dcTableTree.getId());
          TableVO tableVO = (TableVO)getTableStruct(tableDTO).getObj();
          if (platCode.contains("-History"))
            tableVO.setTable_en_name(tableVO.getTable_en_name() + "_history"); 
          if (tableVO != null && !CollectionUtils.isEmpty(tableVO.getField_info())) {
            dcTableTree.setField_info(tableVO.getField_info());
          } else {
            dcTableTree.setField_info(new ArrayList());
          } 
        } else {
          dcTableTree.setField_info(new ArrayList());
        } 
        if (!CollectionUtils.isEmpty(directoryTreeVO.getChildren()))
          dcTableTree.setChildren(getRecurveTable(platCode, new ArrayList<>(), directoryTreeVO.getChildren(), parentId, includeFieldInfo)); 
        tableTreeList.add(dcTableTree);
      }  
    return tableTreeList;
  }
  
  private List<DirectoryTreeVO> transformDirectoryTreeEntity(List<DirectoryTreeVO> metadataDirectoryVOList) {
    List<DirectoryTreeVO> directoryTreeList = new ArrayList<>();
    for (MetadataDirectoryVO metadataDirectoryVO : metadataDirectoryVOList) {
      DirectoryTreeVO directoryTree = new DirectoryTreeVO();
      BeanUtils.copyProperties(metadataDirectoryVO, directoryTree);
      directoryTreeList.add(directoryTree);
    } 
    return directoryTreeList;
  }
  
  private void getTableStructByPlatCode(TableVO tableVO, String tableId, String directoryId, String platCode) {
    IDataResource dataResource = (IDataResource)ServiceUtil.getDataResourceManager(platCode, IDataResource.class);
    ResAndDataDirectoryDTO metadataDirectory = MetadataManager.selectDirectoryByDirectoryId(Long.valueOf(Long.parseLong(directoryId)), platCode, DCConst.DataResourceCategory.DATA);
    SelectMetadataEntityVO metadataEntity = (SelectMetadataEntityVO)dataResource.getMetadataEntityByDirectoryId(Long.valueOf(Long.parseLong(directoryId)), WorkerId.getNextId(), DCConst.DataResourceCategory.DATA, platCode, null).getObj();
    if (metadataDirectory != null && metadataEntity != null) {
      tableVO.setTable_id(tableId);
      tableVO.setTable_cn_name(metadataDirectory.getDirectoryName());
      tableVO.setTable_en_name(metadataEntity.getEntityTableName());
      tableVO.setData_source_type(metadataEntity.getDbType());
      if (metadataEntity.isTableIsSync()) {
        EntityItemInfoSearchDTO entityItemInfoSearchDTO = new EntityItemInfoSearchDTO();
        entityItemInfoSearchDTO.setEntityId(metadataEntity.getEntityId());
        entityItemInfoSearchDTO.setParentInfoItemId(null);
        entityItemInfoSearchDTO.setPlatCode(platCode);
        entityItemInfoSearchDTO.setTokenId(WorkerId.getNextId());
        entityItemInfoSearchDTO.setIsResources(DCConst.DataResourceCategory.DATA);
        QueryModelDTO query = new QueryModelDTO();
        query.setPageIndex(Integer.valueOf(0));
        query.setPageSize(Integer.valueOf(-1));
        entityItemInfoSearchDTO.setQuery(query);
        List<SortModelDTO> sortModels = new ArrayList<>();
        SortModelDTO sortModelDTO = new SortModelDTO();
        sortModelDTO.setFieldName("lzdc_sys_serial_number");
        sortModelDTO.setSortType(Integer.valueOf(0));
        sortModels.add(sortModelDTO);
        entityItemInfoSearchDTO.getQuery().setSortModels(sortModels);
        List<MetadataFieldVO> metadataFieldList = (List<MetadataFieldVO>)((IInfoItem)ServiceUtil.getInfoItemManager(platCode, IInfoItem.class)).getInfoItemListForLZDP(entityItemInfoSearchDTO).getObj();
        if (!CollectionUtils.isEmpty(metadataFieldList)) {
          List<Long> fieldIds = (List<Long>)metadataFieldList.stream().map(MetadataFieldVO::getInfoItemId).collect(Collectors.toList());
          List<DataDesensitizePO> desensitizePOS = ((IDataDesensitizeService)ServiceUtil.getDesensitizeManager(platCode, IDataDesensitizeService.class)).checkDataDesensitize(fieldIds);
          List<FieldVO> fieldList = new ArrayList<>();
          for (MetadataFieldVO metadataField : metadataFieldList) {
            if (metadataField.getInfoItemStatus().intValue() == 1) {
              FieldVO fieldVO = new FieldVO();
              fieldVO.setField_id(metadataField.getInfoItemId().toString());
              fieldVO.setField_name(metadataField.getDataItemName());
              fieldVO.setField_new_name(metadataField.getInfoItemName());
              fieldVO.setField_order(metadataField.getInEntityOrder());
              fieldVO.setField_type(transformLZDPDataType(metadataField.getDataType()));
              if (desensitizePOS != null && desensitizePOS.stream().filter(d -> d.getFieldId().equals(metadataField.getInfoItemId())).count() > 0L)
                fieldVO.setIs_desensitization(1); 
              fieldList.add(fieldVO);
            } 
          } 
          tableVO.setField_info(fieldList);
        } 
      } 
    } 
  }
  
  private boolean isPlatHistoryEnabled(Boolean enableHistory, String platCode) {
    if (!Boolean.TRUE.equals(enableHistory))
      return false; 
    if ("Collection".equals(platCode))
      return Boolean.TRUE.equals(this.historyTableConfig.getCollection().getDataTable().getEnableHistory()); 
    if ("Manage".equals(platCode))
      return Boolean.TRUE.equals(this.historyTableConfig.getManage().getDataTable().getEnableHistory()); 
    if ("Apply".equals(platCode))
      return true; 
    return false;
  }
  
  public Integer transformLZDPDataType(String dataType) {
    Integer lzdpFieldType = Integer.valueOf(1);
    if (StringUtils.isEmpty(dataType))
      return lzdpFieldType; 
    switch (dataType) {
      case "String":
        lzdpFieldType = Integer.valueOf(1);
        break;
      case "Int":
      case "Long":
      case "Numeric":
        lzdpFieldType = Integer.valueOf(2);
        break;
      case "DateTime":
        lzdpFieldType = Integer.valueOf(3);
        break;
    } 
    return lzdpFieldType;
  }
  
  private Map<String, Supplier<List<TableTreeVO>>> initFixedChildrenLazyLoadTreeSupplier() {
    Map<String, Supplier<List<TableTreeVO>>> result = new HashMap<>();
    result.put("Collection", () -> Collections.singletonList(collectionDBTableTree()));
    result.putIfAbsent("Collection-History", () -> Collections.singletonList(collectionDBHistoryTableTree()));
    result.put("Manage", () -> Collections.singletonList(manageDBTableTree()));
    result.put("Manage-History", () -> Collections.singletonList(manageDBHistoryTableTree()));
    result.put("Manage_100000000000000000", () -> Collections.singletonList(manageTableTableTree()));
    result.put("Manage-History_100000000000000000", () -> Collections.singletonList(manageTableHistoryTableTree()));
    result.put("Indicator", () -> Collections.singletonList(indicatorDBTableTree()));
    return result;
  }
}
